# Django Form Survey

Django form survey is an application Django to easier create form survey and easy integrated for your project.

![image](https://raw.githubusercontent.com/irfanpule/django-form-surveys/master/docs/screnshots/dashboard-index.png)
## Table of content
- Getting Started 
    - Requirements
    - Installation
    - Configuration
- Customization
    - View
    - Template
- Tutorial

